<?php
/**
 * Plugin Name:Export vers Prepafacile pour WooCommerce
 * Plugin URI: https://www.presta-magician.com
 * Description: Export orders infos to prepafacile
 * Version: 1.0.1
 * Author: Presta Magician
 * Author URI: https://www.presta-magician.com
 * Text Domain: woo2prepafacile
 * Domain Path: /languages
 * Copyright 2020 Presta Magician. All rights reserved.
 * Tested up to: 5.5
 * WC tested up to: 4.3
 **/
if (!defined('WOO2PREPAFACILE_VERSION')) {
    die('-1');
}

class woo2prepafacileAdminAjax
{
    public function __construct()
    {
        add_action('wp_ajax_woo2psaveallsettings', array($this, 'woo2prepafacile_saveallsettings'));
    
        add_action('wp_ajax_woo2psavetrackingnumber', array($this, 'woo2prepafacile_savetrackingnumber'));
        add_action('wp_ajax_woo2pexportorders', array($this, 'woo2prepafacile_exportorders'));
        add_action('wp_ajax_woo2pexportorder', array($this, 'woo2prepafacile_exportorder'));
   
    
        
       
    }

    // admin
  
    public function woo2prepafacile_savetrackingnumber()
    {
        if (!check_ajax_referer('woo2prepafacile-security-nonce', 'security', false) && !in_array('administrator', wp_get_current_user()->roles)) {
            wp_send_json_error('Invalid security token sent.');
            wp_die();
        } else {     

            global $wpdb;
            $tracking_number = sanitize_text_field($_POST['tracking_number']);
            $order_id = (int) $_POST['order_id'];

            $order = wc_get_order( $order_id );
            $shipping_type = sanitize_text_field($_POST['shipping_type']);
            $shipping_name = sanitize_text_field($_POST['shipping_name']);
            $order_weight = sanitize_text_field($_POST['order_weight']);
                   
            $table_name = $wpdb->prefix . "woo2prepafacile";
            $is_order_exist = $wpdb->get_var('SELECT order_id FROM ' . $table_name . ' WHERE order_id=' . (int) $order_id);
            $datetime = date("Y-m-d H:i:s"); 
            if($is_order_exist)
            {
            $wpdb->update($table_name, array('tracking_number' => sanitize_text_field($tracking_number), 'status' => 'wc-'.sanitize_text_field($order->get_status()),'weight' => sanitize_text_field($order_weight),'carrier_id' => sanitize_text_field($shipping_type),'carrier_name' => sanitize_text_field($shipping_name), 'updated' => sanitize_text_field($datetime)), array('order_id' => (int) $order_id));
            }
            else
            {
                
            $wpdb->insert($table_name, array('order_id' => (int) $order_id,'tracking_number' => sanitize_text_field($tracking_number),'status' => 'wc-'.sanitize_text_field($order->get_status()), 'weight' => sanitize_text_field($order_weight),'carrier_id' => sanitize_text_field($shipping_type),'carrier_name' => sanitize_text_field($shipping_name),'created' => sanitize_text_field($datetime), 'updated' => sanitize_text_field($datetime)));
            }
            wp_die();
        }
    }
   

    public function woo2prepafacile_saveallsettings()
    {
        if (!check_ajax_referer('woo2prepafacile-security-nonce', 'security', false) && !in_array('administrator', wp_get_current_user()->roles)) {
            wp_send_json_error('Invalid security token sent.');
            wp_die();
        } else {
      
            $contrat = sanitize_text_field($_POST['contrat']);
            update_option('PREPAFACILE_CONTRAT',$contrat);
            $refExpediteur = sanitize_text_field($_POST['expediteur']);
            update_option('PREPAFACILE_REFEXP',$refExpediteur);
            $stateExport = sanitize_text_field($_POST['stateExport']);
            update_option('PREPAFACILE_STATE_EXPORT',$stateExport);         
            $shippedStatus = sanitize_text_field($_POST['shippedStatus']);
            update_option('PREPAFACILE_STATE_ENVOIE',$shippedStatus);         
  
            wp_die();
        }
    }

    public function woo2prepafacile_exportorders(){
        if (!check_ajax_referer('woo2prepafacile-security-nonce', 'security', false) && !in_array('administrator', wp_get_current_user()->roles)) {
            wp_send_json_error('Invalid security token sent.');
            wp_die();
        } else {
            global $wpdb;
            $table_name = $wpdb->prefix . "woo2prepafacile";
    
            $filename = WOO2PREPAFACILE_PLUGIN_DIR.'export/export.csv';
            $filename_http = WOO2PREPAFACILE_PLUGIN_URL.'export/export.csv';
          
    @unlink($filename);
    $fp = fopen($filename, 'wb');
    fclose($fp);

    $orders = sanitize_text_field($_POST['ordersID']);
    $orders = explode(',',$orders);
    
    $this->addToFeed('"Contenu";', $filename);
    $this->addToFeed('"Produit";', $filename);
    $this->addToFeed('"Garantie / Taux";', $filename);
    $this->addToFeed('"Avis de réception";', $filename);
    $this->addToFeed('"Date de dépôt";', $filename);
    $this->addToFeed('"N° Contrat d\'affranchissement";', $filename);
    $this->addToFeed('"N° Contrat Produit";', $filename);
    $this->addToFeed('"Référence expéditeur";', $filename);
    $this->addToFeed('"Référence courrier";', $filename);
    $this->addToFeed('"Poids";', $filename);
    $this->addToFeed('"Raison sociale";', $filename);
    $this->addToFeed('"Civilité";', $filename);
    $this->addToFeed('"Nom";', $filename);
    $this->addToFeed('"Prénom";', $filename);
    $this->addToFeed('"Identité / Service / Etage";', $filename);
    $this->addToFeed('"Bâtiment / Immeuble";', $filename);
    $this->addToFeed('"N° et libellé de voie";', $filename);
    $this->addToFeed('"Lieu-dit / BP";', $filename);
    $this->addToFeed('"Code postal";', $filename);
    $this->addToFeed('"Ville";', $filename);
    $this->addToFeed("\r\n", $filename); 
    
    
    foreach ($orders as $order) {
  
      $woo_order = wc_get_order( $order );
      $prepafacile_order = $wpdb->get_row('SELECT * FROM ' . $table_name . ' WHERE order_id="' . (int) $order.'"');
   
  
    $contrat = get_option('PREPAFACILE_CONTRAT');
    $refExpediteur = get_option('PREPAFACILE_REFEXP');        
 
        $date = strftime("%d/%m/%Y");
        $type = "LS";
        $contenu = "";

        if ($prepafacile_order->carrier_id=='LS')
        {
            $type = "LS";
            $contenu = "Marchandise";
        }    
        if ($prepafacile_order->carrier_id=='SIG')
        {
            $type = "2W";            
        }    
        if ($prepafacile_order->carrier_id=='NOSIG')
        {
            $type = "2V";            
        }    
        if ($prepafacile_order->carrier_id=='LE')
        {
            $type = "2M";            
        }    
        
            $this->addToFeed('"' . $contenu .'";', $filename);  // contenu
            $this->addToFeed('"' . $type . '";', $filename); // Produit
            $this->addToFeed('"";', $filename); // Garantie
            $this->addToFeed('"";', $filename); // Avis reception
            $this->addToFeed('"' . $date . '";', $filename); // Date dépot
            $this->addToFeed('"' . $contrat . '";', $filename); // Contrat affranchissement
            $this->addToFeed('"";', $filename); // Contrat produit         
            $this->addToFeed('"' . $this->wd_remove_accents($refExpediteur) . '";', $filename); // reference expediteur
            $this->addToFeed('"' . $order . '";', $filename); // Reference courrier
            $this->addToFeed('"' . $prepafacile_order->weight . '";', $filename); // Poids
          if ($woo_order->get_shipping_company() != '') {
                $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_company()) . '";', $filename); // Raison sociale
                $this->addToFeed('"";', $filename); // Civilité
               $this->addToFeed('"";', $filename); // Nom
               $this->addToFeed('"";', $filename); // Prenom
               $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_first_name()) . ' ' . $this->wd_remove_accents($woo_order->get_shipping_last_name()) . '";', $filename); // Identite service etage
            } else {
                $this->addToFeed('"";', $filename); // Raison sociale
                $this->addToFeed('"";', $filename); // Civilité
                $this->addToFeed('"' . str_replace('"', '""', $this->wd_remove_accents($woo_order->get_shipping_last_name())) . '";', $filename); // Nom
                $this->addToFeed('"' . str_replace('"', '""', $this->wd_remove_accents($woo_order->get_shipping_first_name())) . '";', $filename); // Prenom
                $this->addToFeed('"";', $filename); // Identite service etage
            }
            $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_address_2()) . '";', $filename); // Batiment adresse 2
            $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_address_1()) . '";', $filename); // Adresse 1
            $this->addToFeed('"";', $filename);  // Lieu dit autre
            $this->addToFeed('"' . $woo_order->get_shipping_postcode() . '";', $filename); // Code postal
            $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_city()) . '";', $filename); // ville
            //     addToFeed('"' . $addressDelivery->phone . '";', $filename);
      //      addToFeed('"' . $addressDelivery->phone_mobile . '";', $filename);
     //       addToFeed('"' . $customer->email . '";', $filename);
   
        $this->addToFeed("\r\n", $filename);
    }

    echo $filename_http;

wp_die();


        }
    }

    public function woo2prepafacile_exportorder(){
        if (!check_ajax_referer('woo2prepafacile-security-nonce', 'security', false) && !in_array('administrator', wp_get_current_user()->roles)) {
            wp_send_json_error('Invalid security token sent.');
            wp_die();
        } else {
            global $wpdb;
            $table_name = $wpdb->prefix . "woo2prepafacile";
    
            $filename = WOO2PREPAFACILE_PLUGIN_DIR.'export/export.csv';
            $filename_http = WOO2PREPAFACILE_PLUGIN_URL.'export/export.csv';
    @unlink($filename);
    $fp = fopen($filename, 'wb');
    fclose($fp);

    $order = sanitize_text_field($_POST['order_id']);
    
    $this->addToFeed('"Contenu";', $filename);
    $this->addToFeed('"Produit";', $filename);
    $this->addToFeed('"Garantie / Taux";', $filename);
    $this->addToFeed('"Avis de réception";', $filename);
    $this->addToFeed('"Date de dépôt";', $filename);
    $this->addToFeed('"N° Contrat d\'affranchissement";', $filename);
    $this->addToFeed('"N° Contrat Produit";', $filename);
    $this->addToFeed('"Référence expéditeur";', $filename);
    $this->addToFeed('"Référence courrier";', $filename);
    $this->addToFeed('"Poids";', $filename);
    $this->addToFeed('"Raison sociale";', $filename);
    $this->addToFeed('"Civilité";', $filename);
    $this->addToFeed('"Nom";', $filename);
    $this->addToFeed('"Prénom";', $filename);
    $this->addToFeed('"Identité / Service / Etage";', $filename);
    $this->addToFeed('"Bâtiment / Immeuble";', $filename);
    $this->addToFeed('"N° et libellé de voie";', $filename);
    $this->addToFeed('"Lieu-dit / BP";', $filename);
    $this->addToFeed('"Code postal";', $filename);
    $this->addToFeed('"Ville";', $filename);
    $this->addToFeed("\r\n", $filename); 
    
    
      $woo_order = wc_get_order( $order );
   //   $prepafacile_order = $wpdb->get_row('SELECT * FROM ' . $table_name . ' WHERE order_id="' . (int) $order.'"');
   $weight =  sanitize_text_field($_POST['order_weight']);
   $shipping_type =  sanitize_text_field($_POST['shipping_type']);
  
    $contrat = get_option('PREPAFACILE_CONTRAT');
    $refExpediteur = get_option('PREPAFACILE_REFEXP');        
 
        $date = strftime("%d/%m/%Y");
        $type = "LS";
        $contenu = "";

        if ($shipping_type=='LS')
        {
            $type = "LS";
            $contenu = "Marchandise";
        }    
        if ($shipping_type=='SIG')
        {
            $type = "2W";            
        }    
        if ($shipping_type=='NOSIG')
        {
            $type = "2V";            
        }    
        if ($shipping_type=='LE')
        {
            $type = "2M";            
        }    
        
            $this->addToFeed('"' . $contenu .'";', $filename);  // contenu
            $this->addToFeed('"' . $type . '";', $filename); // Produit
            $this->addToFeed('"";', $filename); // Garantie
            $this->addToFeed('"";', $filename); // Avis reception
            $this->addToFeed('"' . $date . '";', $filename); // Date dépot
            $this->addToFeed('"' . $contrat . '";', $filename); // Contrat affranchissement
            $this->addToFeed('"";', $filename); // Contrat produit         
            $this->addToFeed('"' . $this->wd_remove_accents($refExpediteur) . '";', $filename); // reference expediteur
            $this->addToFeed('"' . $order . '";', $filename); // Reference courrier
            $this->addToFeed('"' . $weight . '";', $filename); // Poids
          if ($woo_order->get_shipping_company() != '') {
                $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_company()) . '";', $filename); // Raison sociale
                $this->addToFeed('"";', $filename); // Civilité
               $this->addToFeed('"";', $filename); // Nom
               $this->addToFeed('"";', $filename); // Prenom
               $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_first_name()) . ' ' . $this->wd_remove_accents($woo_order->get_shipping_last_name()) . '";', $filename); // Identite service etage
            } else {
                $this->addToFeed('"";', $filename); // Raison sociale
                $this->addToFeed('"";', $filename); // Civilité
                $this->addToFeed('"' . str_replace('"', '""', $this->wd_remove_accents($woo_order->get_shipping_last_name())) . '";', $filename); // Nom
                $this->addToFeed('"' . str_replace('"', '""', $this->wd_remove_accents($woo_order->get_shipping_first_name())) . '";', $filename); // Prenom
                $this->addToFeed('"";', $filename); // Identite service etage
            }
            $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_address_2()) . '";', $filename); // Batiment adresse 2
            $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_address_1()) . '";', $filename); // Adresse 1
            $this->addToFeed('"";', $filename);  // Lieu dit autre
            $this->addToFeed('"' . $woo_order->get_shipping_postcode() . '";', $filename); // Code postal
            $this->addToFeed('"' . $this->wd_remove_accents($woo_order->get_shipping_city()) . '";', $filename); // ville
            //     addToFeed('"' . $addressDelivery->phone . '";', $filename);
      //      addToFeed('"' . $addressDelivery->phone_mobile . '";', $filename);
     //       addToFeed('"' . $customer->email . '";', $filename);
   
        $this->addToFeed("\r\n", $filename);

        }

        echo $filename_http;

        wp_die();
    }


   
    private function cut_string_using_last($character, $string, $side, $keep_character = true)
    {
        $offset = ($keep_character ? 1 : 0);
        $whole_length = strlen($string);
        $right_length = (strlen(strrchr($string, $character)) - 1);
        $left_length = ($whole_length - $right_length - 1);
        switch ($side) {
            case 'left':
                $piece = substr($string, 0, ($left_length + $offset));
                break;
            case 'right':
                $start = (0 - ($right_length + $offset));
                $piece = substr($string, $start);
                break;
            default:
                $piece = false;
                break;
        }
        return $piece;
    }

    private function formatCarrier($strcarrier)
    {
        if ($strcarrier[0] == ",")
            $strcarrier = substr($strcarrier, 1);
        if (substr($strcarrier, -1) == ",")
            $strcarrier = substr($strcarrier, 0, -1);

        return $strcarrier;
    }

     
private function addToFeed($str, $filename) {
    if (file_exists($filename)) {
        $fp = fopen($filename, 'ab');
        fwrite($fp, $str);
        fclose($fp);
    }
}

private function wd_remove_accents($str, $charset = 'utf-8') {
    $str = htmlentities($str, ENT_NOQUOTES, $charset);
    $str = preg_replace('#&([A-za-z])(?:acute|cedil|caron|circ|grave|orn|ring|slash|th|tilde|uml);#', '\1', $str);
    $str = preg_replace('#&([A-za-z]{2})(?:lig);#', '\1', $str); // pour les ligatures e.g. '&oelig;'
    $str = preg_replace('#&[^;]+;#', '', $str); // supprime les autres caractères
    return $str;
}


}

new woo2prepafacileAdminAjax();
