<?php
/**
 * Plugin Name: Export vers Prepafacile pour Woocommerce
 * Plugin URI: https://wordpress.org/plugins/export-vers-prepafacile-pour-woocommerce
 * Description: Export orders infos to prepafacile
 * Version: 1.0.2
 * Author: Presta Magician
 * Author URI: https://www.presta-magician.com
 * Text Domain: woo2prepafacile
 * Domain Path: /languages
 * Copyright 2020 - 2022 Presta Magician. All rights reserved.
 * Tested up to: 6.1
 * WC tested up to: 7.0.0
 **/
if (!defined('ABSPATH')) {
    exit;
}
define('WOO2PREPAFACILE_VERSION', '1.0.2');
define('WOO2PREPAFACILE_PLUGIN_URL', plugins_url('/', __FILE__));
define('WOO2PREPAFACILE_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('WOO2PREPAFACILE_PLUGIN_PATH', basename(dirname(__FILE__)));

class WOO2PrepafacileSettings
{

    public function __construct()
    {
        if (is_admin()) {
            add_option('WOO2PREPAFACILE_VERSION', WOO2PREPAFACILE_VERSION);
            include_once 'controllers/admin/woo2prepafacile-admin-ajax.php';
            add_filter('plugin_action_links', array($this, 'woo2p_add_plugin_action_links'), 10, 2);
            add_filter('plugin_row_meta', array($this, 'woo2p_add_plugin_meta_links'), 10, 2);
            add_action('admin_notices', array($this, 'woo2p_global_note'));
        }
        add_action('add_meta_boxes', array($this, 'woo2p_add_shop_order_meta_box'));
        add_action('init', array($this, 'woo2p_init'));
        add_action("woocommerce_order_status_changed", array($this, 'woo2p_orderstatuschanged'), 10, 3);
        add_filter('wc_order_statuses', array($this,'woo2p_add_custom_order_statuses'),10,1);
        add_filter( 'bulk_actions-edit-shop_order', array($this,'woo2p_custom_dropdown_bulk_actions_shop_order'), 50, 1 );
        add_action('plugins_loaded', array($this, 'load_plugin_textdomain'));
  
    }
   
    function woo2p_add_custom_order_statuses($order_statuses) {
        $new_order_statuses = array();
    
        foreach ($order_statuses as $key => $status) {
            $new_order_statuses[$key] = $status;
            if ('wc-processing' === $key) {
                $new_order_statuses['wc-shipped'] = __('Shipped', 'woo2prepafacile' );
            }
        }
        return $new_order_statuses;
    }

    function woo2p_custom_dropdown_bulk_actions_shop_order( $actions ) {
        $new_actions = array();
    
        foreach ($actions as $key => $action) {
            if ('mark_processing' === $key)
                $new_actions['mark_shipped'] = __( 'Change status to shipped', 'woocommerce' );
    
            $new_actions[$key] = $action;
        }
        return $new_actions;
    }  

    public function woo2p_add_shop_order_meta_box()
    {
        add_meta_box(
            'prepafacile_tracking',
            __('Export vers Prepafacile', 'woo2prepafacile'),
            array($this, 'woo2p_shop_order_display_callback'),
            'shop_order',
            'side',
            'core'
        );
    }

    public function woo2p_shop_order_display_callback($post)
    {
        $order_id = $post->ID;

        global $wpdb;
        $is_prepafacile = false;
        $tracking_number = '';
        $carrier_id = '';
        $track_info = '';
        $table_name = $wpdb->prefix . "woo2prepafacile";
        $display = 'none';

        $prepafacile = $wpdb->get_row('SELECT * FROM ' . $table_name . ' WHERE order_id=' . (int) $order_id);
        if (is_object($prepafacile)){
        $is_prepafacile = true;
        $display = 'block';
        }

        if ($is_prepafacile) {
            $tracking_number = $prepafacile->tracking_number;
            $carrier_id = $prepafacile->carrier_id;
            $track_info = $prepafacile->track_info;
        } 
        $order = wc_get_order($order_id);
        $total_weight = 0;
        foreach ($order->get_items() as $item_id => $product_item) {
            $quantity = $product_item->get_quantity(); 
            $product = $product_item->get_product(); 
            $product_weight = (float)$product->get_weight(); 
            $total_weight += floatval($product_weight * $quantity);
        }        

        if ($is_prepafacile){
        echo '<p style="text-align: center">
        <button type="button"
                class="button"
                id="prepafacile_order_tracking_display"
                title="Show Tracking">' . esc_html__('Show Tracking', 'woo2prepafacile') . '            
        </button>
        </p>';
        }
        else{
            echo '<p style="text-align: center">
            <button type="button"
                    class="button"
                    id="prepafacile_order_tracking_display"
                    title="Create Tracking">' . esc_html__('Create Tracking', 'woo2prepafacile') . '            
            </button>
        </p>';
        }
        echo '<div id="woo2p_display_box" style="display:none;"><span>'.esc_html__('Shipping Method:', 'woo2prepafacile').'</span>';
        echo '<select id="shipping_type" name="shipping_type">';
        echo '<option value="LS" ' . selected('LS', $carrier_id, true) . ' >Lettre Suivi</option>';
        echo '<option value="SIG" ' . selected('SIG', $carrier_id, true) . '>Courrier Forfait Poids avec Signature (ex Frequenceo Signature)</option>';
        echo '<option value="NOSIG" ' . selected('NOSIG', $carrier_id, true) . '>Courrier Forfait Poids Sans Signature (ex Frequenceo Sans Signature)</option>';
        echo '<option value="LE" ' . selected('LE', $carrier_id, true) . '>Lettre Expert (Remise contre signature)</option>';
        echo '</select>';
        echo '<br><br><span>' . esc_html__('Shipping Number:', 'woo2prepafacile') . '</span><br>';
        echo '<input type="text" id="prepafacile_tracking_number" name="prepafacile_tracking_number" value="' . esc_attr($tracking_number) . '" />';
        echo '<a id= "woo2p_preview_tracking_link" class="woo2p_preview_tracking_link" target="_blank" href="#"><span class="dashicons dashicons-admin-site-alt"></span></a>';
        echo '<br><br><span>'.esc_html__('Total Weight:', 'woo2prepafacile').'</span><br>';
        echo '<input type="text" id="prepafacile_order_weight" name="prepafacile_order_weight" value="' . esc_attr($total_weight) . '" />';

 //       echo '<br><br><span>Last Info:</span><br>';
 //       echo '<input type="text" id="prepafacile_tracking_info" name="prepafacile_tracking_info" value="' . esc_attr($track_info) . '" />';

        echo '<br><p style="text-align: center">
                <button type="button"
                        class="button"
                        data-order_id="' . esc_attr($order_id) . '"
                        id="prepafacile_order_tracking"
                        title="Update">' . esc_html__('Create/Update Tracking', 'woo2prepafacile') . '
                        <span class="fas fa-spinner fa-spin" style="display:none;"></span>					
                </button>
            </p><br><hr>';
           
        echo '<p id="prepafacile_order_export_container" style="text-align: center; display:' . $display .'">
            <button type="button"
                    class="button"
                    data-order_id="' . esc_attr($order_id) . '"
                    id="prepafacile_order_export"
                    title="Export">' . esc_html__('Export vers Prepafacile*', 'woo2prepafacile') . '
                    <span class="fas fa-spinner fa-spin" style="display:none;"></span>					
            </button><br>
            <a id="woo2p_export_order_file_link" href="#"></a>
        </p></div>';
    }

    public function woo2p_global_note()
    {
        if (!is_plugin_active('woocommerce/woocommerce.php')) {
            ?>
            <div id="message" class="error">
                <p><?php _e('Please install and activate WooCommerce to use Prepafacile* for Woocomerce.', 'woo2prepafacile');?></p>
            </div>
            <?php
        }
    }

    public function woo2p_add_plugin_action_links($links, $plugin_name)
    {
        if (strpos($plugin_name, basename(__FILE__))) {
            $settings_link = array();
            $settings_link['settings'] = sprintf('<a href="%s">%s</a>', admin_url('admin.php?page=woo2prepafacile-settings'), esc_html__('Settings', 'woo2prepafacile'));
            $settings_link['docs'] = sprintf( '<a href="%s" target="_blank">%s</a>', WOO2PREPAFACILE_PLUGIN_URL . 'readme_fr.pdf', esc_html__( 'Docs', 'woo2prepafacile' ) );
	
          return array_merge( $settings_link, $links );
        }
        return $links;
    }
    public function woo2p_add_plugin_meta_links($links, $plugin_name)
    {
        if (strpos($plugin_name, basename(__FILE__))) {
            $links[] = '<b><a style="color:red;" href="https://www.presta-magician.com/fr/plugins-pour-wordpress/22-woo2prepafacile.html" target="_blanck">' . __('Upgrade to Premium', 'woo2prepafacile') . '</a></b>';
        }
        return $links;
    }

    public function load_plugin_textdomain()
    {
          load_plugin_textdomain('woo2prepafacile', false, WOO2PREPAFACILE_PLUGIN_PATH . '/languages/');
    }

    public function woo2p_init()
    {
        add_action('admin_menu', array($this, 'woo2prepafacile_settings_add_plugin_page'));
        add_action('admin_init', array($this, 'woo2prepafacile_settings_page_init'));

        register_post_status('wc-shipped ', array(
            'label' => __( 'Shipped', 'woo2prepafacile' ),
            'public' => true,
            'exclude_from_search' => false,
            'show_in_admin_all_list' => true,
            'show_in_admin_status_list' => true,
            'label_count' => _n_noop('Shipped <span class="count">(%s)</span>', 'Shipped <span class="count">(%s)</span>')
        ));
    }

    public function woo2prepafacile_settings_add_plugin_page()
    {
        add_menu_page(
            'Woo2Prepafacile',
            'Export vers Prepafacile',
            'manage_options',
            'woo2prepafacile-settings',
            array($this, 'woo2prepafacile_settings_create_admin_page'),
            'dashicons-location'
        );

        add_submenu_page(
            'woo2prepafacile-settings',
            esc_html__( 'Settings', 'woo2prepafacile' ),
            esc_html__( 'Settings', 'woo2prepafacile' ),
            'manage_options',
            'woo2prepafacile-settings',
            array($this, 'woo2prepafacile_settings_create_admin_page')
        );

        add_submenu_page(
            'woo2prepafacile-settings',
            esc_html__('Export vers Prepafacile', 'woo2prepafacile'),
            esc_html__('Export vers Prepafacile', 'woo2prepafacile'),
            'manage_options',
            'woo2prepafacile-export',
            array($this, 'prepafacile_export_callback')
        );
    }

    public function woo2prepafacile_settings_create_admin_page()
    {
        $export_status = get_option('PREPAFACILE_STATE_EXPORT');
        $shipped_status = get_option('PREPAFACILE_STATE_ENVOIE');
        $contrat = get_option('PREPAFACILE_CONTRAT');
        $expediteur = get_option('PREPAFACILE_REFEXP');
   /*   $CarriersString = get_option('PREPAFACILE_CARRIERS');
        $arrayCarriers = explode(",", $CarriersString);
        $LettreSuivi = get_option('PREPAFACILE_LS');
        $LettreSuivi = explode(",", $LettreSuivi);
        $signe = get_option('PREPAFACILE_FREQUENCEO_SIGNE');
        $signe = explode(",", $signe);
        $nosigne = get_option('PREPAFACILE_FREQUENCEO_NOSIGNE');
        $nosigne = explode(",", $nosigne);
        $LettreExpert = get_option('PREPAFACILE_LETTRE_EXPERT');
        $LettreExpert = explode(",", $LettreExpert);*/

        $all_status = wc_get_order_statuses();

        $shipping_classes = get_terms(array('taxonomy' => 'product_shipping_class', 'hide_empty' => false));

        ?>
		<div class="wrap woo2prepafacile-admin-settings">
			<h1><?php _e('Settings', 'woo2prepafacile')?></h1>
            <div class="notice notice-info"><p><?php echo sprintf( '<a href="%s" target="_blank">%s</a>', WOO2PREPAFACILE_PLUGIN_URL . 'readme_fr.pdf', esc_html__( 'See the Documentation.', 'woo2prepafacile' ) ); ?></p></div>
            <div class="notice notice-info"><p><?php  _e('* Prepafacile is a registered trademark of La Poste.<br> Presta Magician has no connection with La Poste.', 'woo2prepafacile'); ?></p></div>
      
       
         
        	<form method="post">
			<input type="hidden" name="updated" value="true" />
			<table class="form-table">
			   	<tbody>
                   <th><label for="woo2prepafacile_contrat"><?php _e('Prepafacile* Contract Number', 'woo2prepafacile')?></label></th>
                    		    <td><input required name="woo2prepafacile_contrat" id="woo2prepafacile_contrat" type="text" value="<?php echo $contrat; ?>" class="regular-text" />
							    <span class="woo2p_required_field"> * </span>
                                <br><span class="wwo2p_description"><?php _e('* Required. See your Prepafacile* Contract.', 'woo2prepafacile')?></span><br>
							    </td>
                    	    </tr>
							<tr>
                    <th><label for="woo2prepafacile_expeditor"><?php _e('Expeditor Reference', 'woo2prepafacile')?></label></th>
					<td><input required name="woo2prepafacile_expeditor" id="woo2prepafacile_expeditor" type="text" value="<?php echo $expediteur; ?>" class="regular-text" />
					<span class="woo2p_required_field"> * </span>
                    <br><span class="wwo2p_description"><?php _e('* Required. Can to be your store name or other.', 'woo2prepafacile')?></span><br>
					</td>
				    </tr>
                       <tr>
						<th><label for="woo2prepafacile_export_status"><?php _e('Select an Export Status', 'woo2prepafacile')?></label></th>
                    		<td><select name="woo2prepafacile_export_status" id="woo2prepafacile_export_status">
							<?php
                    foreach ($all_status as $key => $status) {
                    ?>
					    <option value="<?php echo $key; ?>" <?php selected($key, $export_status, true);?>><?php echo $status; ?></option>
				<?php }
                ?>
                    </select>
                    <br><span class="wwo2p_description"><?php _e('It is the order status when the order infos can to be exported to prepafacile*.', 'woo2prepafacile')?></span><br>
                    </td>
                  	</tr>
					<tr>
					<th><label for="woo2prepafacile_shipped_status"><?php _e('Select a Shipped Status', 'woo2prepafacile')?></label></th>
                  		<td><select name="woo2prepafacile_shipped_status" id="woo2prepafacile_shipped_status">
							<?php
                    foreach ($all_status as $key => $status) {
                ?>
				    <option value="<?php echo $key; ?>" <?php selected($key, $shipped_status, true);?>><?php echo $status; ?></option>
				<?php }
                ?>
                    </select>
                    <br><span class="wwo2p_description"><?php _e('It is the order status when the order is shipped.', 'woo2prepafacile')?></span><br>
                    <span class="wwo2p_description"><?php _e('The plugin has created a new order status: "Shipped" that you can to use if you want.', 'woo2prepafacile')?></span>
                    </td>
                    </tr>
                </table>
    <!--                            <table class="form-table" >
                         <tr><th> <label class=""><?php _e('Select Carriers', 'woo2prepafacile')?></label></th>


							<td><table cellspacing="0" cellpadding="0" id="woo2prepafacile_carriers_table">
                                <thead>
                                <tr>
                                    <th></th>
                                    <th><span class="title_box active"><?php _e('ID', 'woo2prepafacile')?></span></th>
                                    <th><span class="title_box active"><?php _e('Carrier Name', 'woo2prepafacile')?></span></th>
                                    <th><span class="title_box active"><?php _e('Shipping Type', 'woo2prepafacile')?></span></th>
                                </tr>
                            </thead>
       /*       <?php
                $irow = 0;
                foreach ($shipping_classes as $carrier) {
            /*    if (in_array($carrier->term_id, $arrayCarriers)) {
                $checked = true;
                } else {
                $checked = false;
                }*/
                ?>
                            <tbody>
                             <?php $irow = $irow + 1;?>

                                <tr class="<?php if ($irow % 2 == 0) {?> woo2p_odd <?php }?>">
                               <?php
                if ($checked) {
                                ?>
                                                <td><input type="checkbox" name="carrierBox" class="carrierBox" id="carrierBox_<?php echo $carrier->term_id; ?>'" value="<?php echo $carrier->term_id; ?>" checked /></td>
                                                        <td><?php echo $carrier->term_id; ?></td>
                                                        <td><label for="carrierBox_<?php echo $carrier->term_id; ?>" class="t"><?php echo $carrier->name; ?></label></td>
                                                        <td>
                                                            <select id="shiptype_<?php echo $carrier->term_id; ?>" name="typeBox">
                                                                <option value="LS_<?php echo $carrier->term_id; ?>"
                                                                    <?php
                if (in_array($carrier->term_id, $LettreSuivi)) {
                                    ?>
                                                                    selected="true">Lettre Suivi</option>
                                                                    <?php
                } else {?>
                                                                        >Lettre Suivi</option>
                                                                <?php }?>
                                                                <option value="SIG_<?php echo $carrier->term_id; ?>"
                                                                    <?php
                if (in_array($carrier->term_id, $signe)) {
                                    ?>
                                                                    selected="true">Courrier Forfait Poids avec Signature (ex Frequenceo Signature)</option>
                                                                    <?php
                } else {?>
                                                                        >Courrier Forfait Poids avec Signature (ex Frequenceo Signature)</option>
                                                                <?php }?>
                                                                <option value="NOS_<?php echo $carrier->term_id; ?>"
                                                                    <?php
                if (in_array($carrier->term_id, $nosigne)) {
                                    ?>
                                                                    selected="true">Courrier Forfait Poids Sans Signature (ex Frequenceo Sans Signature)</option>
                                                                    <?php
                } else {?>
                                                                        >Courrier Forfait Poids Sans Signature (ex Frequenceo Sans Signature)</option>
                                                                <?php }?>
                                                                <option value="LE_<?php echo $carrier->term_id; ?>"
                                                                    <?php
                if (in_array($carrier->term_id, $LettreExpert)) {
                                    ?>
                                                                    selected="true">Lettre Expert (Remise contre signature)</option>
                                                                    <?php
                } else {?>
                                                                        >Lettre Expert (Remise contre signature)</option>
                                                                <?php }?>


                                                            </select>
                                                        </td>
                                                                    <?php } else {?>
                                                        <td><input type="checkbox" name="carrierBox" class="carrierBox" id="carrierBox_<?php echo $carrier->term_id; ?>" value="<?php echo $carrier->term_id; ?>" /></td>
                                                        <td><?php echo $carrier->term_id; ?></td>
                                                        <td><label for="carrierBox_<?php echo $carrier->term_id; ?>" class="t"><?php echo $carrier->name; ?></label></td>
                                                        <td>
                                                            <select id="shiptype_<?php echo $carrier->term_id; ?>" name="typeBox">

                                                                <option value="LS_<?php echo $carrier->term_id; ?>" >Lettre Suivi</option>
                                                                <option value="SIG_<?php echo $carrier->term_id; ?>" >Courrier Forfait Poids avec Signature (ex Frequenceo Signature)</option>
                                                                <option value="NOS_<?php echo $carrier->term_id; ?>" >Courrier Forfait Poids Sans Signature (ex Frequenceo Sans Signature)</option>
                                                                <option value="LE_<?php echo $carrier->term_id; ?>" >Lettre Expert (Remise contre signature)</option>

                                                            </select></td>

                                                                <?php }?>



                                                </tr>
                                            </tbody>
                                            <?php }?>*/
                                    
                                            </table></td></tr> 
                                                                    </table> -->




                                    <p class="submit">
                                        <button type="button" name="woo2prepafacile_save_all_settings" id="woo2prepafacile_save_all_settings" class="button button-primary"><?php _e('Save the settings', 'woo2prepafacile')?>
                                        <span class="fas fa-spinner fa-spin" style="display:none;"></span>
                                        </button>
                                    </p>
                            </form>
                        </div>
	<?php }

    public function woo2prepafacile_settings_page_init()
    {
        include_once 'languages/js-translate.php';

        wp_enqueue_style('woo2prepafacile-admin-css', WOO2PREPAFACILE_PLUGIN_URL . 'assets/css/admin.css',array(),$this->version_id(),'all');
        wp_enqueue_script('woo2prepafacile-admin-js', WOO2PREPAFACILE_PLUGIN_URL . 'assets/js/admin.min.js', array('jquery'));
        wp_localize_script('woo2prepafacile-admin-js', 'woo2prepafacile_admin_ajax_object',
            [
                'ajax_url' => admin_url('admin-ajax.php'),
                'security' => wp_create_nonce('woo2prepafacile-security-nonce'),
            ]
        );
           wp_localize_script('woo2prepafacile-admin-js', 'woo2prepafacileTranslate', $translation_array);
    }

    public function prepafacile_export_callback()
    {
        $export_status = get_option('PREPAFACILE_STATE_EXPORT');
        $shipped_status = get_option('PREPAFACILE_STATE_ENVOIE');
        $contrat = get_option('PREPAFACILE_CONTRAT');
        $expediteur = get_option('PREPAFACILE_REFEXP');

        global $wpdb;
        $table_name = $wpdb->prefix . "woo2prepafacile";
        $prepafacile_orders = $wpdb->get_results('SELECT * FROM ' . $table_name . ' WHERE status="' . sanitize_text_field($export_status) . '"');
        ?>
		<div class="wrap woo2prepafacile-admin-settings">
			<h1><?php _e('Export Orders to Prepafacile*', 'woo2prepafacile')?></h1>
            <div class="notice notice-info"><p><?php echo sprintf( '<a href="%s" target="_blank">%s</a>', WOO2PREPAFACILE_PLUGIN_URL . 'readme_fr.pdf', esc_html__( 'See the Documentation.', 'woo2prepafacile' ) ); ?></p></div>
            <div class="notice notice-info"><p><?php  _e('* Prepafacile is a registered trademark of La Poste.<br> Presta Magician has no connection with La Poste.', 'woo2prepafacile'); ?></p></div>
      
            <div class="woo2p_alert alert-info" role="alert"><span class="dashicons dashicons-editor-help"></span><span class="woo2p_alert_title">Comment exporter les commandes vers Prepafacile* ?</span>
                <ul>
                    <li>Ci dessous se trouve le tableau des commandes exportables vers Prepafacile*.</li>
                    <li>Dans l'édition des commandes, vous devez avoir choisi un type d'envoi associé à Prepafacile* et défini le statut d'export des commandes dans la configuration du plugin.</li>
                    <li>En cliquant sur le bouton "Créer le fichier d'import dans Prepafacile*", un fichier CSV va être créé avec les commandes sélectionnées.</li>
                    <li>Un lien sera affiché avec le fichier à télécharger.</li>
                    <li>Ce fichier pourra alors être importé dans Prepafacile*.</li>
                    <li>Dans Prepafacile*, il faudra faire le mappage des colonnes en choisissant l'import par <b> Référence Courrier </b> et non par référence destinataire.</li>
                    <li>De même, la Référence Courrier doit être associée au N° de commande Woocommerce.</li> 
                </ul>
            </div><br />
			<form name="woo2p_exportPrepafacile" id="woo2p_exportPrepafacile" method="post">
			<input type="hidden" name="updated" value="true" />
            <div>
            <span class="woo2prepafacile_export_orders_title">Commandes ayant le statut: <?php echo $export_status; ?> et exportable vers Prepafacile*.</span>
                <table cellspacing="0" cellpadding="0" class="form-table" name="mytab" style="text-align:center;">
                <thead>
                    <tr id="woo2prepafacile_export_orders_table">
                        <th style="text-align:center;"><input type="checkbox" name="checkme" id="ckeckAll" class="noborder"  /></th>
                        <th style="text-align:center;">ID</th>
                        <th style="text-align:center;">Client</th>
                        <th style="text-align:center;">Date</th>
                        <th style="text-align:center;">Prix total</th>
                        <th style="text-align:center;">Prix Transport</th>
                        <th style="text-align:center;">Poids</th>
                        <th style="text-align:center;">Pays</th>
                        <th style="text-align:center;">Transporteur</th>
                        <th style="text-align:center;">Voir Détails</th>
                    </tr>
            </thead>

                    <?php
        $irow = 0;
        foreach ($prepafacile_orders as $orderinfos) {
            $weight = '';
            $irow = $irow + 1;
            $order = wc_get_order($orderinfos->order_id);
            ?>

                        <tr class="<?php if ($irow % 2 == 0) {?> woo2p_odd <?php }?>">

                        <td><input type="checkbox" name="orderBoxPrepafacile" class="woo2p_export_prepafacile" id="orderBoxPrepafacile_<?php echo $orderinfos->order_id; ?>" value="<?php echo $orderinfos->order_id; ?>" checked/></td>
                        <td><?php echo $orderinfos->order_id; ?></td>
                        <td>Uniquement disponible avec la version Premium</td>
                        <td></td>
                        <td></td>
                        <td></td>
                        <td></td>
                        <td></td>
                        <td></td>
                        <td></td>


                        </tr>

<?php
}
        ?>
                </table></div><div class="margin-form" style="margin-top:10px">

				    <p class="submit">
                        <button type="button" name="woo2prepafacile_export_orders" id="woo2prepafacile_export_orders" class="button button-primary"><?php _e('Create CSV file to import in Prepafacile*', 'woo2prepafacile')?>
					    <span class="fas fa-spinner fa-spin" style="display:none;"></span>
						</button>
                    </p>
                    <span id="woo2p_export_orders_file_info" >Voici le lien du fichier à télécharger:</span> <a id="woo2p_export_orders_file_link" href=""></a>
			</form>
        </div>

<br>
<hr>
<br>

        <div class="woo2p_alert alert-info" role="alert"><span class="dashicons dashicons-editor-help"></span><span class="woo2p_alert_title">Comment importer de PrepaFacile* vers Woocommerce afin de mettre à jour le N° de suivi des colis ainsi que le statut de la commande ?</span>
    <ul>
        <li>Après la création des étiquettes d'envoie, un fichier a été créé dans PrepaFacile*.(voir doc PrepaFacile*)</li>
        <li>Choisissez ce fichier en cliquant sur le bouton "Parcourir" puis ensuite cliquez sur le bouton "Import".</li>
        <li>Dans ce fichier, le N° de suivi doit se trouver à la position 0 et la référence courrier (à la position 11 en partant de 0) doit contenir le N° de commande.</li>
        <li>Une fois l'import fait, le statut de la commande sera modifié avec le statut d'envoi de la commande sélectionné dans la configuration du plugin.</li>
        <li>Le N° de suivi sera ajouté dans les informations de la commande.</li> 
        <li>Et un email de suivi des colis sera envoyé aux clients (uniquement pour la version Premium).</li>
        <li>De même les informations de suivi sont indiqués dans la page de visualisation des commandes des comptes clients (uniquement pour la version Premium).</li>
 
    </ul>
</div><br />


<div class="panel col-lg-12" >
   <span> Uniquement disponible avec la version Premium </span>
</div>
	<?php
}

    public function woo2p_orderstatuschanged($order_id, $status_transition_from, $status_transition_to)
    {
        global $woocommerce;
        global $wpdb;
        $table_name = $wpdb->prefix . "woo2prepafacile";

        $order = new WC_Order($order_id);

        $shipped_status = get_option('PREPAFACILE_STATE_ENVOIE');

        $shipped_status = str_replace('wc-', '', $shipped_status);
        $datetime = date("Y-m-d H:i:s");        

        $wpdb->update($table_name, array('status' => 'wc-'.sanitize_text_field($order->get_status()), 'updated' => sanitize_text_field($datetime)), array('order_id' => (int) $order_id));      

        $prepafacile_order = $wpdb->get_row('SELECT * FROM ' . $table_name . ' WHERE order_id="' . (int) $order_id . '"');

     
    }

    function version_id() {
        if ( WP_DEBUG )
          return time();
        return WOO2PREPAFACILE_VERSION;
      }
      

}

$woo2prepafacile_settings = new WOO2PrepafacileSettings();
if (is_admin()) {
    include_once 'controllers/admin/woo2prepafacile-admin-installdb.php';
    register_activation_hook(__FILE__, 'woo2prepafacile_install');
}
